Class: Kobot::Config

Inherits:
Object
  • Object
show all
Defined in:
lib/kobot/config.rb

Overview

Configuration definition includes static ones hardcoded and dynamic ones that can be specified by command line options.

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.auto_skipObject

Returns the value of attribute auto_skip.



8
9
10
# File 'lib/kobot/config.rb', line 8

def auto_skip
  @auto_skip
end

.auto_skip_withoutObject

Returns the value of attribute auto_skip_without.



8
9
10
# File 'lib/kobot/config.rb', line 8

def auto_skip_without
  @auto_skip_without
end

.browser_geolocationObject

Returns the value of attribute browser_geolocation.



8
9
10
# File 'lib/kobot/config.rb', line 8

def browser_geolocation
  @browser_geolocation
end

.browser_headlessObject

Returns the value of attribute browser_headless.



8
9
10
# File 'lib/kobot/config.rb', line 8

def browser_headless
  @browser_headless
end

.browser_wait_timeoutObject

Returns the value of attribute browser_wait_timeout.



8
9
10
# File 'lib/kobot/config.rb', line 8

def browser_wait_timeout
  @browser_wait_timeout
end

.clockObject

Returns the value of attribute clock.



8
9
10
# File 'lib/kobot/config.rb', line 8

def clock
  @clock
end

.credentials_fileObject

Returns the value of attribute credentials_file.



8
9
10
# File 'lib/kobot/config.rb', line 8

def credentials_file
  @credentials_file
end

.dryrunObject

Returns the value of attribute dryrun.



8
9
10
# File 'lib/kobot/config.rb', line 8

def dryrun
  @dryrun
end

.forceObject

Returns the value of attribute force.



8
9
10
# File 'lib/kobot/config.rb', line 8

def force
  @force
end

.gmail_notify_enabledObject

Returns the value of attribute gmail_notify_enabled.



8
9
10
# File 'lib/kobot/config.rb', line 8

def gmail_notify_enabled
  @gmail_notify_enabled
end

.gmail_notify_subjectObject

Returns the value of attribute gmail_notify_subject.



8
9
10
# File 'lib/kobot/config.rb', line 8

def gmail_notify_subject
  @gmail_notify_subject
end

.gmail_notify_toObject

Returns the value of attribute gmail_notify_to.



8
9
10
# File 'lib/kobot/config.rb', line 8

def gmail_notify_to
  @gmail_notify_to
end

.gmail_smtp_addressObject

Returns the value of attribute gmail_smtp_address.



8
9
10
# File 'lib/kobot/config.rb', line 8

def gmail_smtp_address
  @gmail_smtp_address
end

.gmail_smtp_portObject

Returns the value of attribute gmail_smtp_port.



8
9
10
# File 'lib/kobot/config.rb', line 8

def gmail_smtp_port
  @gmail_smtp_port
end

.kot_date_formatObject

Returns the value of attribute kot_date_format.



8
9
10
# File 'lib/kobot/config.rb', line 8

def kot_date_format
  @kot_date_format
end

.kot_timezone_offsetObject

Returns the value of attribute kot_timezone_offset.



8
9
10
# File 'lib/kobot/config.rb', line 8

def kot_timezone_offset
  @kot_timezone_offset
end

.kot_urlObject

Returns the value of attribute kot_url.



8
9
10
# File 'lib/kobot/config.rb', line 8

def kot_url
  @kot_url
end

.loglevelObject

Returns the value of attribute loglevel.



8
9
10
# File 'lib/kobot/config.rb', line 8

def loglevel
  @loglevel
end

.skipObject

Returns the value of attribute skip.



8
9
10
# File 'lib/kobot/config.rb', line 8

def skip
  @skip
end

Class Method Details

.configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:

  • _self (Kobot::Config)

    the object that the method was called on



28
29
30
# File 'lib/kobot/config.rb', line 28

def configure
  yield self
end