Class: Kobot::Config
- Inherits:
-
Object
- Object
- Kobot::Config
- Defined in:
- lib/kobot/config.rb
Overview
Configuration definition includes static ones hardcoded and dynamic ones that can be specified by command line options.
Class Attribute Summary collapse
-
.auto_skip ⇒ Object
Returns the value of attribute auto_skip.
-
.auto_skip_without ⇒ Object
Returns the value of attribute auto_skip_without.
-
.browser_geolocation ⇒ Object
Returns the value of attribute browser_geolocation.
-
.browser_headless ⇒ Object
Returns the value of attribute browser_headless.
-
.browser_wait_timeout ⇒ Object
Returns the value of attribute browser_wait_timeout.
-
.clock ⇒ Object
Returns the value of attribute clock.
-
.credentials_file ⇒ Object
Returns the value of attribute credentials_file.
-
.dryrun ⇒ Object
Returns the value of attribute dryrun.
-
.force ⇒ Object
Returns the value of attribute force.
-
.gmail_notify_enabled ⇒ Object
Returns the value of attribute gmail_notify_enabled.
-
.gmail_notify_subject ⇒ Object
Returns the value of attribute gmail_notify_subject.
-
.gmail_notify_to ⇒ Object
Returns the value of attribute gmail_notify_to.
-
.gmail_smtp_address ⇒ Object
Returns the value of attribute gmail_smtp_address.
-
.gmail_smtp_port ⇒ Object
Returns the value of attribute gmail_smtp_port.
-
.kot_date_format ⇒ Object
Returns the value of attribute kot_date_format.
-
.kot_timezone_offset ⇒ Object
Returns the value of attribute kot_timezone_offset.
-
.kot_url ⇒ Object
Returns the value of attribute kot_url.
-
.loglevel ⇒ Object
Returns the value of attribute loglevel.
-
.skip ⇒ Object
Returns the value of attribute skip.
Class Method Summary collapse
Class Attribute Details
.auto_skip ⇒ Object
Returns the value of attribute auto_skip.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def auto_skip @auto_skip end |
.auto_skip_without ⇒ Object
Returns the value of attribute auto_skip_without.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def auto_skip_without @auto_skip_without end |
.browser_geolocation ⇒ Object
Returns the value of attribute browser_geolocation.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def browser_geolocation @browser_geolocation end |
.browser_headless ⇒ Object
Returns the value of attribute browser_headless.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def browser_headless @browser_headless end |
.browser_wait_timeout ⇒ Object
Returns the value of attribute browser_wait_timeout.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def browser_wait_timeout @browser_wait_timeout end |
.clock ⇒ Object
Returns the value of attribute clock.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def clock @clock end |
.credentials_file ⇒ Object
Returns the value of attribute credentials_file.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def credentials_file @credentials_file end |
.dryrun ⇒ Object
Returns the value of attribute dryrun.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def dryrun @dryrun end |
.force ⇒ Object
Returns the value of attribute force.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def force @force end |
.gmail_notify_enabled ⇒ Object
Returns the value of attribute gmail_notify_enabled.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def gmail_notify_enabled @gmail_notify_enabled end |
.gmail_notify_subject ⇒ Object
Returns the value of attribute gmail_notify_subject.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def gmail_notify_subject @gmail_notify_subject end |
.gmail_notify_to ⇒ Object
Returns the value of attribute gmail_notify_to.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def gmail_notify_to @gmail_notify_to end |
.gmail_smtp_address ⇒ Object
Returns the value of attribute gmail_smtp_address.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def gmail_smtp_address @gmail_smtp_address end |
.gmail_smtp_port ⇒ Object
Returns the value of attribute gmail_smtp_port.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def gmail_smtp_port @gmail_smtp_port end |
.kot_date_format ⇒ Object
Returns the value of attribute kot_date_format.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def kot_date_format @kot_date_format end |
.kot_timezone_offset ⇒ Object
Returns the value of attribute kot_timezone_offset.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def kot_timezone_offset @kot_timezone_offset end |
.kot_url ⇒ Object
Returns the value of attribute kot_url.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def kot_url @kot_url end |
.loglevel ⇒ Object
Returns the value of attribute loglevel.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def loglevel @loglevel end |
.skip ⇒ Object
Returns the value of attribute skip.
8 9 10 |
# File 'lib/kobot/config.rb', line 8 def skip @skip end |
Class Method Details
.configure {|_self| ... } ⇒ Object
28 29 30 |
# File 'lib/kobot/config.rb', line 28 def configure yield self end |